<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About iTALC</source>
        <translation>Om iTALC</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://italc.sourceforge.net&quot;&gt;http://italc.sourceforge.net&lt;/a&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authors</source>
        <translation type="unfinished">Upphovsmän</translation>
    </message>
    <message>
        <source>Translation</source>
        <translation type="unfinished">Översättning</translation>
    </message>
    <message>
        <source>Current language not translated yet (or native English).

If you&apos;re interested in translating iTALC into your local or another language or want to improve an existing translation, please contact an iTALC developer!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License</source>
        <translation type="unfinished">Licens</translation>
    </message>
    <message>
        <source>iTALC - Intelligent Teaching And Learning with Computers

Copyright © 2004-2013 Tobias Doerffel / iTALC Solutions</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AccessDialogSlave</name>
    <message>
        <source>Never for this session</source>
        <translation>Aldrig för denna session</translation>
    </message>
    <message>
        <source>Always for this session</source>
        <translation>Alltid för denna session</translation>
    </message>
    <message>
        <source>Confirm desktop access</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The user %1 at host %2 wants to access your desktop. Do you want to grant access?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClassroomManager</name>
    <message>
        <source>Classroom-Manager</source>
        <translation>Klassrumshanterare</translation>
    </message>
    <message>
        <source>Use this workspace to manage your computers and classrooms in an easy way.</source>
        <translation>Använd denna arbetsyta för att hantera dina datorer och klassrum på ett enkelt sätt.</translation>
    </message>
    <message>
        <source>This is where computers and classrooms are managed. You can add computers or classrooms by clicking right in this list.</source>
        <translation>Detta är där datorer och klassrum hanteras. Du kan lägga till datorer eller klassrum genom att klicka till i listan.</translation>
    </message>
    <message>
        <source>Classrooms/computers</source>
        <translation>Klassrum/datorer</translation>
    </message>
    <message>
        <source>IP-address</source>
        <translation>IP-adress</translation>
    </message>
    <message>
        <source>Usernames</source>
        <translation>Användarnamn</translation>
    </message>
    <message>
        <source>Show usernames</source>
        <translation>Visa användarnamn</translation>
    </message>
    <message>
        <source>Use the context-menu (right mouse-button) to add/remove computers and/or classrooms.</source>
        <translation>Använd sammanhangsmenyn (höger musknapp) för att lägga till/ta bort datorer och/eller klassrum.</translation>
    </message>
    <message>
        <source>Export to text-file</source>
        <translation>Exportera till textfil</translation>
    </message>
    <message>
        <source>Use this button for exporting this list of computers and usernames into a text-file. You can use this file later for collecting files after an exam has finished. This is sometimes necessary, because some users might have finished and logged out earlier and so you cannot collect their files at the end of the exam.</source>
        <translation>Använd denna knapp för att exportera denna lista över datorer och användarnamn till en textfil. Du kan använda denna fil senare för att samla in filer efter ett prov har avslutats. Detta är ibland nödvändigt därför att vissa användare kanske har gjort färdigt provet tidigt och loggat ut och på sätt kan du inte samla in deras filer när provet avslutas.</translation>
    </message>
    <message>
        <source>Hide teacher computers</source>
        <translation>Dölj lärardatorer</translation>
    </message>
    <message>
        <source>Show/hide</source>
        <translation>Visa/dölj</translation>
    </message>
    <message>
        <source>Edit settings</source>
        <translation>Redigera inställningar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Ta bort</translation>
    </message>
    <message>
        <source>Show all computers in classroom</source>
        <translation>Visa alla datorer i klassrummet</translation>
    </message>
    <message>
        <source>Hide all computers in classroom</source>
        <translation>Dölj alla datorer i klassrummet</translation>
    </message>
    <message>
        <source>Edit name</source>
        <translation>Redigera namn</translation>
    </message>
    <message>
        <source>Remove classroom</source>
        <translation>Ta bort klassrum</translation>
    </message>
    <message>
        <source>Add computer</source>
        <translation>Lägg till dator</translation>
    </message>
    <message>
        <source>Add classroom</source>
        <translation>Lägg till klassrum</translation>
    </message>
    <message>
        <source>No configuration-file found</source>
        <translation>Ingen konfigurationsfil hittades</translation>
    </message>
    <message>
        <source>Could not open configuration file %1.
You will have to add at least one classroom and computers using the classroom-manager which you&apos;ll find inside the program in the sidebar on the left side.</source>
        <translation>Kunde inte öppna konfigurationsfilen %1.
Du måste lägga till minst ett klassrum och datorer med hjälp av klassrumshanteraren som du hittar inuti programmet i vänstra sidopanelen.</translation>
    </message>
    <message>
        <source>Error in configuration-file</source>
        <translation>Fel i konfigurationsfilen</translation>
    </message>
    <message>
        <source>Error while parsing configuration-file %1.
Please edit it. Otherwise you should delete this file and have to add all classrooms and computers again.</source>
        <translation>Fel vid tolkning av konfigurationsfilen %1.
Du måste redigera den. Om inte så bör du ta bort denna fil och lägga till alla klassrum och datorer igen.</translation>
    </message>
    <message>
        <source>Error while parsing configuration-file %1.
Please edit it. Otherwise you should delete this file.</source>
        <translation>Fel vid tolkning av konfigurationsfilen %1.
Du måste redigera den. Om inte så bör du ta bort denna fil.</translation>
    </message>
    <message>
        <source>Select output-file</source>
        <translation>Välj utdatafil</translation>
    </message>
    <message>
        <source>Text files (*.txt)</source>
        <translation>Textfiler (*.txt)</translation>
    </message>
    <message>
        <source>Actions for selected</source>
        <translation>Åtgärder för markerade</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Åtgärder</translation>
    </message>
    <message>
        <source>Actions for %1</source>
        <translation>Åtgärder för %1</translation>
    </message>
    <message>
        <source>New name for classroom</source>
        <translation>Nytt namn för klassrum</translation>
    </message>
    <message>
        <source>Please enter a new name for classroom &quot;%1&quot;.</source>
        <translation>Ange ett nytt namn för klassrummet &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Are you sure want to remove classroom &quot;%1&quot;?
All computers in it will be removed as well!</source>
        <translation>Är du säker på att du vill ta bort klassrummet &quot;%1&quot;?
Alla datorer i det kommer även att tas bort!</translation>
    </message>
    <message>
        <source>Missing classroom</source>
        <translation>Saknar klassrum</translation>
    </message>
    <message>
        <source>Before adding computers you have to create at least one classroom.
Do you want to create a new classrom now?</source>
        <translation>Du måste skapa minst ett klassrum innan du kan lägga till datorer.
Vill du skapa ett nytt klassrum nu?</translation>
    </message>
    <message>
        <source>New classroom</source>
        <translation>Nytt klassrum</translation>
    </message>
    <message>
        <source>Please enter the name of the classroom you want to create.</source>
        <translation>Ange namnet på det klassrum som du vill skapa.</translation>
    </message>
</context>
<context>
    <name>Client</name>
    <message>
        <source>Unknown state</source>
        <translation>Okänt tillstånd</translation>
    </message>
    <message>
        <source>No user logged in</source>
        <translation>Ingen användare inloggad</translation>
    </message>
    <message>
        <source>Host unreachable</source>
        <translation>Värddatorn är inte nåbar</translation>
    </message>
    <message>
        <source>Demo running</source>
        <translation>Demonstration körs</translation>
    </message>
    <message>
        <source>Desktop locked</source>
        <translation>Skrivbordet är låst</translation>
    </message>
</context>
<context>
    <name>ClientAction</name>
    <message>
        <source>Are you sure want logout all users on all visible computers ?</source>
        <translation>Är du säker på att du vill logga ut alla användare på alla synliga datorer?</translation>
    </message>
    <message>
        <source>Are you sure want logout all users on all selected computers ?</source>
        <translation>Är du säker på att du vill logga ut alla användare på alla markerade datorer?</translation>
    </message>
    <message>
        <source>Logout user</source>
        <translation>Logga ut användare</translation>
    </message>
    <message>
        <source>Are you sure want to reboot all visible computers?</source>
        <translation>Är du säker på att du vill starta om alla synliga datorer?</translation>
    </message>
    <message>
        <source>Are you sure want to reboot all selected computers?</source>
        <translation>Är du säker på att du vill starta om alla markerade datorer?</translation>
    </message>
    <message>
        <source>Reboot computers</source>
        <translation>Starta om datorer</translation>
    </message>
    <message>
        <source>Are you sure want to power down all visible computers?</source>
        <translation>Är du säker på att du vill stänga av alla synliga datorer?</translation>
    </message>
    <message>
        <source>Are you sure want to power down all selected computers?</source>
        <translation>Är du säker på att du vill stänga av alla markerade datorer?</translation>
    </message>
</context>
<context>
    <name>ClientSettingsDialog</name>
    <message>
        <source>Invalid MAC-address</source>
        <translation>Ogiltig MAC-adress</translation>
    </message>
    <message>
        <source>You specified an invalid MAC-address. Either leave the field blank or enter a valid MAC-address (use &quot;:&quot; as separator!).</source>
        <translation>Du angav en ogiltig MAC-adress. Lämna fältet tomt eller ange en giltig MAC-adress (använd &quot;:&quot; som avgränsare!).</translation>
    </message>
    <message>
        <source>Client settings</source>
        <translation type="unfinished">Klientinställningar</translation>
    </message>
    <message>
        <source>IP/hostname</source>
        <translation type="unfinished">IP/värdnamn</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;enter an IP-address or hostname under which iTALC can reach the client (use &apos;:&apos; for specifying an optional port-number)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;ange en IP-adress eller värdnamn med vilket iTALC kan nå klienten (använd &quot;:&quot; för att ange ett valfritt portnummer)&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Namn</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Optional nickname of the host which is displayed in iTALC.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Valfritt smeknamn på värddatorn som kommer att visas i iTALC.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>MAC address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Hardware/MAC-address of client - only used for powering on client&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Maskinvaru-/MAC-adress för klienten - används endast för att starta klienten&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Classroom</source>
        <translation type="unfinished">Klassrum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Typ</translation>
    </message>
    <message>
        <source>Student computer</source>
        <translation type="unfinished">Studentdator</translation>
    </message>
    <message>
        <source>Teacher computer</source>
        <translation type="unfinished">Lärardator</translation>
    </message>
    <message>
        <source>Other/undefined computer</source>
        <translation type="unfinished">Annan/odefinierad dator</translation>
    </message>
    <message>
        <source>Missing IP address/hostname</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You didn&apos;t specify an IP address or hostname for the computer!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Config</name>
    <message>
        <source>Interval between updates</source>
        <translation>Intervall mellan uppdateringar</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Here you can set the interval between updates of clients. Higher values result in lower network-traffic and lower CPU-usage on this computer.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Här kan du ställa in intervallet mellan uppdateringar av klienter. Högre värden resulterar i lägre nätverkstrafik och lägre processorbelastning på denna dator.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source> seconds</source>
        <translation>sekunder</translation>
    </message>
    <message>
        <source>User interface</source>
        <translation>Användargränssnitt</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Do not show balloon-tooltips for toolbar-buttons&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Visa inte ballongtips för verktygsradsknappar&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Check this option if you&apos;re annoyed by the balloon-tooltips appearing when moving mouse-cursor over toolbar-buttons.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Använd detta alternativ om du blir besvärad av ballongtips som visas när muspekaren rör sig över verktygsradsknapparna.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>No balloon-tooltips</source>
        <translation>Inga ballongtips</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Do not show texts on toolbar-buttons&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Visa inte text på verktygsradsknappar&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>No texts on toolbar-buttons</source>
        <translation>Ingen text på verktygsradsknappar</translation>
    </message>
    <message>
        <source>Your role (needs according keys!)</source>
        <translation>Din roll (kräver motsvarande nycklar!)</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Here you can select your role. Only change this if you know what you&apos;re doing. Otherwise you won&apos;t be able to access any clients until you restore your old role.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Här kan du välja din roll. Ändra endast detta om du vet vad du gör. Om du gör fel så kanske du inte kan komma åt några klienter förrän du har återställt till din gamla roll.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Teacher</source>
        <translation>Lärare</translation>
    </message>
    <message>
        <source>Administrator</source>
        <translation>Administratör</translation>
    </message>
    <message>
        <source>Supporter</source>
        <translation>Supportperson</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Annan</translation>
    </message>
    <message>
        <source>Settings for multi-logon</source>
        <translation>Inställningar för flerinloggning</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation>Domän</translation>
    </message>
    <message>
        <source>Double-click action for client-window</source>
        <translation>Dubbelklicksåtgärd för klientfönster</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Here you can set what should happen if you double-click a client-window.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Här kan du ställa in vad som ska hända när du dubbelklickar i ett klientfönster.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation>Fjärrstyrning</translation>
    </message>
    <message>
        <source>View live in fullscreen</source>
        <translation>Visa live i helskärm</translation>
    </message>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-style:italic;&quot;&gt;Please note, that some changes won&apos;t take effect until you restart iTALC.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;/head&gt;&lt;body style=&quot; white-space: pre-wrap; font-family:Sans Serif; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:8pt; font-style:italic;&quot;&gt;Observera att vissa ändringar inte blir aktiva förrän du startar om iTALC.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ar - العربية</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cs - Česky</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>de - Deutsch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>el - Ελληνικά</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>es - Español</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fi - Suomi</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>fr - Français</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>he - עִבְרִית</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>hu - Magyar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>it - Italiano</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>nl - Nederlands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>nn - Norsk</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pl - Polski</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pt_br - Brasileiro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pt_pt - Português</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ru - Русский</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sk - Slovenský</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sl - Slovenčina</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>sv - Svenska</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>tr - Türkçe</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>uk - Українська</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zh_cn - 简体字</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>zh_tw - 簡體字</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConfigWidget</name>
    <message>
        <source>Your iTALC-configuration</source>
        <translation>Din iTALC-konfiguration</translation>
    </message>
    <message>
        <source>In this workspace you can customize iTALC to fit your needs.</source>
        <translation>I denna arbetsyta kan du anpassa iTALC till att passa dina behov.</translation>
    </message>
</context>
<context>
    <name>DecoratedMessageBox</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>DemoClient</name>
    <message>
        <source>iTALC Demo</source>
        <translation>iTALC-demo</translation>
    </message>
</context>
<context>
    <name>ItalcCoreServer</name>
    <message>
        <source>Authentication error</source>
        <translation>Autentiseringsfel</translation>
    </message>
    <message>
        <source>Somebody (IP: %1) tried to access this computer but could not authenticate itself successfully!</source>
        <translation>Någon (IP: %1) försökte komma åt denna dator men kunde inte autentisera sig korrekt!</translation>
    </message>
</context>
<context>
    <name>ItalcVncConnection</name>
    <message>
        <source>VNC authentication failed because of too many authentication tries.</source>
        <translation>VNC-autentisering misslyckades på grund av för många autentiseringsförsök.</translation>
    </message>
    <message>
        <source>VNC authentication failed.</source>
        <translation>VNC-autentisering misslyckades.</translation>
    </message>
    <message>
        <source>VNC server closed connection.</source>
        <translation>VNC-servern stängde anslutningen.</translation>
    </message>
</context>
<context>
    <name>KeyFileAssistant</name>
    <message>
        <source>iTALC Access Key Assistant</source>
        <translation type="unfinished">Guide för iTALC-åtkomstnycklar</translation>
    </message>
    <message>
        <source>Create/import iTALC access keys</source>
        <translation type="unfinished">Skapa/importera iTALC-åtkomstnycklar</translation>
    </message>
    <message>
        <source>This assistant will help you to create or import iTALC access keys.</source>
        <translation type="unfinished">Denna guide hjälper dig att skapa eller importera iTALC-åtkomstnycklar.</translation>
    </message>
    <message>
        <source>How does it work?</source>
        <translation type="unfinished">Hur fungerar det?</translation>
    </message>
    <message>
        <source>iTALC access keys consist of two parts belonging together, a private and a public key part.

Using the private key part, users on the master computer will be able to access client computers. It is important that only authorized users have read access to the private key file.

The public key part is used on the client computers to verify that any incoming connection request is authorized.</source>
        <translation type="unfinished">iTALC-åtkomstnycklar består av två delar som tillhör varandra, en privat och en publik nyckeldel.

Användare på huvuddatorn kan komma åt klientdatorer med den privata nyckeldelen. Det är viktigt att endast behöriga användare har läsrättigheter till den privata nyckeldelen.

Den publika delen används på klientdatorerna för att verifiera att inkommande anslutningar är behöriga.</translation>
    </message>
    <message>
        <source>Assistant mode</source>
        <translation type="unfinished">Guideläge</translation>
    </message>
    <message>
        <source>Please choose whether to create new access keys or import a public key on a client.</source>
        <translation type="unfinished">Välj huruvida du vill skapa nya åtkomstnycklar eller importera en publik nyckel på en klient.</translation>
    </message>
    <message>
        <source>Create new access keys (master computer)</source>
        <translation type="unfinished">Skapa nya åtkomstnycklar (huvuddator)</translation>
    </message>
    <message>
        <source>assistantModeButtonGroup</source>
        <translation type="unfinished">assistantModeButtonGroup</translation>
    </message>
    <message>
        <source>Import public key (client computer)</source>
        <translation type="unfinished">Importera publik nyckel (klientdator)</translation>
    </message>
    <message>
        <source>Select user role</source>
        <translation type="unfinished">Välj användarroll</translation>
    </message>
    <message>
        <source>Please select a user role for which to create or import the access keys:</source>
        <translation type="unfinished">Välj en användarroll för vilken åtkomstnycklarna ska skapas eller importeras:</translation>
    </message>
    <message>
        <source>Teacher</source>
        <translation type="unfinished">Lärare</translation>
    </message>
    <message>
        <source>Administrator</source>
        <translation type="unfinished">Administratör</translation>
    </message>
    <message>
        <source>Support team member</source>
        <translation type="unfinished">Medlem av supportgrupp</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished">Annan</translation>
    </message>
    <message>
        <source>User roles allow using multiple access keys in parallel. For example there can be different teacher access keys for each classroom while the support access keys are the same for the whole school.</source>
        <translation type="unfinished">Användarroller tillåter att man använder flera åtkomstnycklar samtidigt. Till exempel kan det finnas olika åtkomstnycklar för lärare för varje klassrum men åtkomstnycklar för supportpersoner kan gälla för hela skolan.</translation>
    </message>
    <message>
        <source>Directories</source>
        <translation type="unfinished">Kataloger</translation>
    </message>
    <message>
        <source>Export public key part (master computer)</source>
        <translation type="unfinished">Exportera publik nyckeldel (huvuddator)</translation>
    </message>
    <message>
        <source>...</source>
        <translation type="unfinished">...</translation>
    </message>
    <message>
        <source>Use custom destination directory for access keys</source>
        <translation type="unfinished">Använd anpassad målkatalog för åtkomstnycklar</translation>
    </message>
    <message>
        <source>Please specify the location of the public access key to be imported.</source>
        <translation type="unfinished">Ange platsen för den publika åtkomstnyckeln som ska importeras.</translation>
    </message>
    <message>
        <source>Summary</source>
        <translation type="unfinished">Sammandrag</translation>
    </message>
    <message>
        <source>The following actions will be taken:</source>
        <translation type="unfinished">Följande åtgärder kommer att genomföras:</translation>
    </message>
    <message>
        <source>• Create new access keys</source>
        <translation type="unfinished">• Skapa nya åtkomstnycklar</translation>
    </message>
    <message>
        <source>• Import public access key from</source>
        <translation type="unfinished">• Importera publik åtkomstnyckel från</translation>
    </message>
    <message>
        <source>&lt;unknown&gt;</source>
        <translation type="unfinished">&lt;okänt&gt;</translation>
    </message>
    <message>
        <source>• Write access key(s) to</source>
        <translation type="unfinished">• Skriv åtkomstnycklar till</translation>
    </message>
    <message>
        <source>• Export public key to</source>
        <translation type="unfinished">• Exportera publik nyckel till</translation>
    </message>
    <message>
        <source>• Configure for user role</source>
        <translation type="unfinished">• Konfigurera för användarrollen</translation>
    </message>
    <message>
        <source>Select directory in which to export the public key</source>
        <translation type="unfinished">Välj katalog att exportera den publika nyckeln till</translation>
    </message>
    <message>
        <source>Key files (*.key.txt)</source>
        <translation type="unfinished">Nyckelfiler (*.key.txt)</translation>
    </message>
    <message>
        <source>Invalid public key</source>
        <translation type="unfinished">Ogiltig publik nyckel</translation>
    </message>
    <message>
        <source>The selected file does not contain a valid public iTALC access key!</source>
        <translation type="unfinished">Det valda filen innehåller inte någon giltig publik iTALC-åtkomstnyckel!</translation>
    </message>
    <message>
        <source>Select destination directory</source>
        <translation type="unfinished">Välj målkatalog</translation>
    </message>
    <message>
        <source>Access key creation</source>
        <translation type="unfinished">Skapa åtkomstnyckel</translation>
    </message>
    <message>
        <source>Could not remove previously existing file %1.</source>
        <translation type="unfinished">Kunde inte ta bort befintliga filen %1.</translation>
    </message>
    <message>
        <source>Failed exporting public access key from %1 to %2.</source>
        <translation type="unfinished">Misslyckades med att exportera publik åtkomstnyckel från %1 till %2.</translation>
    </message>
    <message>
        <source>Access keys were created and written successfully to %1 and %2.</source>
        <translation type="unfinished">Åtkomstnycklar skapades och skrevs till %1 och %2.</translation>
    </message>
    <message>
        <source>An error occured while creating the access keys. You probably are not permitted to write to the selected directories.</source>
        <translation type="unfinished">Ett fel inträffade vid skapandet av åtkomstnycklar. Du har antagligen inte behörighet att skriva till de valda katalogerna.</translation>
    </message>
    <message>
        <source>Public key import</source>
        <translation type="unfinished">Import av publik nyckel</translation>
    </message>
    <message>
        <source>An error occured while importing the public access key. You probably are not permitted to read the source key or to write the destination file.</source>
        <translation type="unfinished">Ett fel inträffade vid import av publik åtkomstnyckel. Du har antagligen inte behörighet att läsa källnyckeln eller skriva till målfilen.</translation>
    </message>
    <message>
        <source>The public key was successfully imported to %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>screen lock</source>
        <translation>skärmlås</translation>
    </message>
</context>
<context>
    <name>LogonGroupEditor</name>
    <message>
        <source>Logon group editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please add the groups whose members should be allowed to access computers in your iTALC network.</source>
        <translation type="unfinished">Lägg till grupperna vars medlemmar ska tillåtas att komma åt datorer i ditt iTALC-nätverk.</translation>
    </message>
    <message>
        <source>All groups</source>
        <translation type="unfinished">Alla grupper</translation>
    </message>
    <message>
        <source>...</source>
        <translation type="unfinished">...</translation>
    </message>
    <message>
        <source>Groups with iTALC privileges</source>
        <translation type="unfinished">Grupper med iTALC-behörighet</translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>Actions</source>
        <translation>Åtgärder</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>General</source>
        <translation>Allmänt</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Avsluta</translation>
    </message>
    <message>
        <source>iTALC Management Console</source>
        <translation>Hanteringskonsoll för iTALC</translation>
    </message>
    <message>
        <source>iTALC Server</source>
        <translation>iTALC-server</translation>
    </message>
    <message>
        <source>Paths</source>
        <translation>Sökvägar</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Autentisering</translation>
    </message>
    <message>
        <source>iTALC Service</source>
        <translation>iTALC-tjänst</translation>
    </message>
    <message>
        <source>Hide tray icon</source>
        <translation>Dölj aktivitetsikonen</translation>
    </message>
    <message>
        <source>Autostart</source>
        <translation>Automatisk start</translation>
    </message>
    <message>
        <source>Additional arguments</source>
        <translation>Ytterligare argument</translation>
    </message>
    <message>
        <source>Start service</source>
        <translation>Starta tjänst</translation>
    </message>
    <message>
        <source>Stop service</source>
        <translation>Stoppa tjänst</translation>
    </message>
    <message>
        <source>State:</source>
        <translation>Tillstånd:</translation>
    </message>
    <message>
        <source>Stopped</source>
        <translation>Stoppad</translation>
    </message>
    <message>
        <source>Logging</source>
        <translation>Loggning</translation>
    </message>
    <message>
        <source>Log file directory</source>
        <translation>Loggfilskatalog</translation>
    </message>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <source>Log level</source>
        <translation>Loggnivå</translation>
    </message>
    <message>
        <source>Nothing</source>
        <translation>Ingenting</translation>
    </message>
    <message>
        <source>Only critical messages</source>
        <translation>Endast kritiska meddelanden</translation>
    </message>
    <message>
        <source>Errors and critical messages</source>
        <translation>Fel och kritiska meddelanden</translation>
    </message>
    <message>
        <source>Warnings and errors</source>
        <translation>Varningar och fel</translation>
    </message>
    <message>
        <source>Information, warnings and errors</source>
        <translation>Information, varningar och fel</translation>
    </message>
    <message>
        <source>Debug messages and everything else</source>
        <translation>Felsökningsmeddelanden och allting annat</translation>
    </message>
    <message>
        <source>Limit log file size</source>
        <translation>Begränsa storlek på loggfil</translation>
    </message>
    <message>
        <source>MB</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>Clear all log files</source>
        <translation>Töm alla loggfiler</translation>
    </message>
    <message>
        <source>Desktop capturing</source>
        <translation>Skrivbordsfångst</translation>
    </message>
    <message>
        <source>Enable capturing of layered (semi-transparent) windows</source>
        <translation>Aktivera fångst av flerskiktade fönster (semi-transparant)</translation>
    </message>
    <message>
        <source>Low accuracy (turbo mode)</source>
        <translation>Låg precision (turboläge)</translation>
    </message>
    <message>
        <source>Demo server</source>
        <translation>Demoserver</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Nätverk</translation>
    </message>
    <message>
        <source>Core server port</source>
        <translation>Serverport för core</translation>
    </message>
    <message>
        <source>Demo server port</source>
        <translation>Serverport för demo</translation>
    </message>
    <message>
        <source>Enable firewall exception</source>
        <translation>Aktivera brandväggsundantag</translation>
    </message>
    <message>
        <source>Configuration files</source>
        <translation>Konfigurationsfiler</translation>
    </message>
    <message>
        <source>Global configuration</source>
        <translation>Allmän konfiguration</translation>
    </message>
    <message>
        <source>Personal configuration</source>
        <translation>Personlig konfiguration</translation>
    </message>
    <message>
        <source>Data directories</source>
        <translation>Datakataloger</translation>
    </message>
    <message>
        <source>Snapshots</source>
        <translation>Skärmbilder</translation>
    </message>
    <message>
        <source>Authentication methods</source>
        <translation>Autentiseringsmetoder</translation>
    </message>
    <message>
        <source>Access key management</source>
        <translation>Hantering av åtkomstnycklar</translation>
    </message>
    <message>
        <source>Logon settings</source>
        <translation>Inloggningsinställningar</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Arkiv</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Hjälp</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>A&amp;vsluta</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Save settings into file</source>
        <translation>&amp;Spara inställningar till fil</translation>
    </message>
    <message>
        <source>Save settings into file</source>
        <translation>Spara inställningar till fil</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>L&amp;oad settings from file</source>
        <translation>&amp;Läs in inställningar från fil</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>About iTALC</source>
        <translation>Om iTALC</translation>
    </message>
    <message>
        <source>About Qt</source>
        <translation>Om Qt</translation>
    </message>
    <message>
        <source>MainWindow</source>
        <translation>Huvudfönster</translation>
    </message>
    <message>
        <source>toolBar</source>
        <translation>verktygsrad</translation>
    </message>
    <message>
        <source>iTALC Management Console %1</source>
        <translation>Hanteringskonsoll för iTALC %1</translation>
    </message>
    <message>
        <source>Running</source>
        <translation>Kör</translation>
    </message>
    <message>
        <source>Load settings from file</source>
        <translation>Läs in inställningar från fil</translation>
    </message>
    <message>
        <source>XML files (*.xml)</source>
        <translation>XML-filer (*.xml)</translation>
    </message>
    <message>
        <source>Save settings to file</source>
        <translation>Spara inställningar till fil</translation>
    </message>
    <message>
        <source>Unsaved settings</source>
        <translation>Osparade inställningar</translation>
    </message>
    <message>
        <source>There are unsaved settings. Quit anyway?</source>
        <translation>Det finns osparade inställningar. Avsluta ändå?</translation>
    </message>
    <message>
        <source>Configuration not writable</source>
        <translation>Konfigurationen är inte skrivbar</translation>
    </message>
    <message>
        <source>The local configuration backend reported that the configuration is not writable! Please run the iTALC Management Console with higher privileges.</source>
        <translation>Den lokala konfigurationsbakänden rapporterade att konfigurationen är inte skrivbar. Kör hanteringskonsollen för iTALC med högre behörighet.</translation>
    </message>
    <message>
        <source>All settings were applied successfully.</source>
        <translation>Alla inställningar verkställdes.</translation>
    </message>
    <message>
        <source>An error occured while applying settings!</source>
        <translation>Ett fel inträffade vid verkställandet av inställningar!</translation>
    </message>
    <message>
        <source>iTALC</source>
        <translation>iTALC</translation>
    </message>
    <message>
        <source>No write access</source>
        <translation>Ingen skrivåtkomst</translation>
    </message>
    <message>
        <source>Could not read/write or create directory %1! For running iTALC, make sure you&apos;re permitted to create or write this directory.</source>
        <translation>Kunde inte läsa/skriva eller skapa katalogen %1! Försäkra dig om att du har behörighet att skapa eller skriva till denna katalog för att kunna köra iTALC.</translation>
    </message>
    <message>
        <source>Classroom</source>
        <translation>Klassrum</translation>
    </message>
    <message>
        <source>Switch classroom</source>
        <translation>Växla klassrum</translation>
    </message>
    <message>
        <source>Click this button to open a menu where you can choose the active classroom.</source>
        <translation>Klicka på denna knapp för att öppna en meny där du kan välja det aktiva klassrummet.</translation>
    </message>
    <message>
        <source>Click on this button, to switch between classrooms.</source>
        <translation>Klicka på denna knapp för att växla mellan klassrum.</translation>
    </message>
    <message>
        <source>Overview mode</source>
        <translation>Översiktsläge</translation>
    </message>
    <message>
        <source>Overview</source>
        <translation>Översikt</translation>
    </message>
    <message>
        <source>This is the default mode in iTALC and allows you to have an overview over all visible computers. Also click on this button for unlocking locked workstations or for leaving demo-mode.</source>
        <translation>Detta är standardläget i iTALC och låter dig få en översikt över alla synliga datorer. Klicka även på denna knapp för att låsa upp låsta arbetsstationer eller för att lämna demoläget.</translation>
    </message>
    <message>
        <source>Fullscreen demo</source>
        <translation>Helskärmsdemo</translation>
    </message>
    <message>
        <source>Fullscreen Demo</source>
        <translation>Helskärmsdemo</translation>
    </message>
    <message>
        <source>Stop Demo</source>
        <translation>Stoppa demo</translation>
    </message>
    <message>
        <source>In this mode your screen is being displayed on all shown computers. Furthermore the users aren&apos;t able to do something else as all input devices are locked in this mode.</source>
        <translation>I detta läge kommer din skärm att visas på alla visade datorer. Användarna kommer dock inte att kunna göra något annat eftersom alla inmatningsenheter blir låsta i denna läge.</translation>
    </message>
    <message>
        <source>Window demo</source>
        <translation>Fönsterdemo</translation>
    </message>
    <message>
        <source>Window Demo</source>
        <translation>Fönsterdemo</translation>
    </message>
    <message>
        <source>In this mode your screen being displayed in a window on all shown computers. The users are able to switch to other windows and thus can continue to work.</source>
        <translation>I detta läge kommer din skärm att visas i ett fönster på alla visade datorer. Användarna kommer att kunna växla till andra fönster och därför kunna fortsätta att arbeta samtidigt.</translation>
    </message>
    <message>
        <source>Lock/unlock desktops</source>
        <translation>Lås/lås upp skrivbord</translation>
    </message>
    <message>
        <source>Lock all</source>
        <translation>Lås alla</translation>
    </message>
    <message>
        <source>Unlock all</source>
        <translation>Lås upp alla</translation>
    </message>
    <message>
        <source>To have all user&apos;s full attention you can lock their desktops using this button. In this mode all input devices are locked and the screen is black.</source>
        <translation>Du kan med denna knapp låsa alla användares skrivbord för att få deras fulla uppmärksamhet. I detta läge kommer alla inmatningsenheter att låsas och skärmen blir svart.</translation>
    </message>
    <message>
        <source>Send text message</source>
        <translation>Skicka textmeddelande</translation>
    </message>
    <message>
        <source>Text message</source>
        <translation>Textmeddelande</translation>
    </message>
    <message>
        <source>Use this button to send a text message to all users e.g. to tell them new tasks etc.</source>
        <translation>Använd denna knapp för att skicka ett textmeddelande till alla användare, t.ex. för att ge dem nya aktiviteter etc.</translation>
    </message>
    <message>
        <source>Power on computers</source>
        <translation>Starta datorer</translation>
    </message>
    <message>
        <source>Power on</source>
        <translation>Starta</translation>
    </message>
    <message>
        <source>Click this button to power on all visible computers. This way you do not have to turn on each computer by hand.</source>
        <translation>Klicka på denna knapp för att starta alla synliga datorer. Med denna funktion så slipper du starta var och en av datorerna för hand.</translation>
    </message>
    <message>
        <source>Power down computers</source>
        <translation>Stäng av datorer</translation>
    </message>
    <message>
        <source>Power down</source>
        <translation>Stäng av</translation>
    </message>
    <message>
        <source>To power down all shown computers (e.g. after the lesson has finished) you can click this button.</source>
        <translation>Du kan klicka på denna knapp för att stänga av alla visade datorer (t.ex. när lektionen är över).</translation>
    </message>
    <message>
        <source>Support</source>
        <translation>Support</translation>
    </message>
    <message>
        <source>Direct support</source>
        <translation>Direktsupport</translation>
    </message>
    <message>
        <source>If you need to support someone at a certain computer you can click this button and enter the according hostname or IP afterwards.</source>
        <translation>Klicka på denna knapp om du behöver ge support till någon på en specifik dator och ange värdnamn eller IP-adress.</translation>
    </message>
    <message>
        <source>Adjust/align</source>
        <translation>Justera/rada upp</translation>
    </message>
    <message>
        <source>Adjust windows and their size</source>
        <translation>Justera fönster och deras storlek</translation>
    </message>
    <message>
        <source>When clicking this button the biggest possible size for the client-windows is adjusted. Furthermore all windows are aligned.</source>
        <translation>Den största möjliga storleken för klientfönstret kommer att justeras när du klickar på denna knapp. Alla fönster kommer även att radas upp.</translation>
    </message>
    <message>
        <source>Auto view</source>
        <translation>Automatisk vy</translation>
    </message>
    <message>
        <source>Auto re-arrange windows and their size</source>
        <translation>Arrangera automatiskt om fönster och deras storlek</translation>
    </message>
    <message>
        <source>When clicking this button all visible windows are re-arranged and adjusted.</source>
        <translation>Alla synliga fönster kommer att arrangeras om och justeras när du klickar på denna knapp.</translation>
    </message>
    <message>
        <source>iTALC Master Control</source>
        <translation>Huvudstyrning - iTALC</translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation>Fjärrstyrning</translation>
    </message>
    <message>
        <source>Could not modify the autostart property for the iTALC Service.</source>
        <translation>Kunde inte ändra autostartsegenskaper för iTALC-tjänsten.</translation>
    </message>
    <message>
        <source>Could not modify the service arguments for the iTALC Service.</source>
        <translation>Kunde inte ändra tjänsteargumenten för iTALC-tjänsten.</translation>
    </message>
    <message>
        <source>Could not change the firewall configuration for the iTALC Service.</source>
        <translation>Kunde inte ändra brandväggskonfigurationen för iTALC-tjänsten.</translation>
    </message>
    <message>
        <source>Debugging</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable desktop switching for screen lock (experimental)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log to standard error output</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log to Windows event log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Backend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>VNC reflector</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iTALC 1 demo server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Multithreading (can be enabled when using the VNC reflector backend)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable HTTP server which provides a JavaViewer applet</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HTTP server port</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow connections from localhost only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Key file authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ACL-based logon authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Public key file base directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Private key file base directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Launch key file assistant</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage permissions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Test</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Access confirmation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can configure iTALC to ask the user for permission to access the desktop when using certain authentication methods.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Logon authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Allow same user to access desktop without confirmation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Debugging iTALC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When encountering bugs or other misbehaviour in iTALC it is important to inform the developers about them, so that the bugs can be fixed in future releases. This page allows you to submit a helpful bug report easily.

If the bug is not reproducible, skip step 1) - 3).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear the logfiles in the &quot;General&quot; section.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In the &quot;General&quot; section set the log level to &quot;Debug messages and everything else&quot;.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Repeat the actions leading to the bug or misbehaviour.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>4)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click the following button and save the file to a known location.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generate bug report archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>5)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Go to the &lt;a href=&quot;http://sourceforge.net/tracker/?group_id=132465&amp;amp;atid=724375&quot;&gt;iTALC bug tracker&lt;/a&gt;, open a new bug, describe what you did in step 3) and attach the file you saved in step 4).&lt;/p&gt;
&lt;br/&gt;
&lt;br/&gt;
Note: if the bug involves both a master and client computer, attach bug report archives for both computers.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Restart iTALC Service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All settings were saved successfully. In order to take effect the iTALC service needs to be restarted. Restart it now?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Starting iTALC service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stopping iTALC service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The iTALC service needs to be stopped temporarily in order to remove the log files. Continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log files cleared</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All log files were cleared successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not remove all log files.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Logon authentication test</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication with provided credentials was successful.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication with provided credentials failed!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save bug report archive</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iTALC bug report archive (*.ibra.xml)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>iTALC bug report archive saved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An iTALC bug report archive has been saved to %1. It includes iTALC log files and information about your operating system. You can attach it to a bug report.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not contact iTALC service</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Could not contact the local iTALC service. It is likely that you entered wrong credentials or key files are not set up properly. Try again or contact your administrator for solving this problem using the iTALC Management Console.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Authentication impossible</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No authentication key files were found or your current ones are outdated. Please create new key files using the iTALC Management Console. Alternatively set up logon authentication using the iTALC Management Console. Otherwise you won&apos;t be able to access computers using iTALC.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Poll full screen (leave this enabled per default)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageBoxSlave</name>
    <message>
        <source>Message from teacher</source>
        <translation>Meddelande från lärare</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600; font-style:italic;&quot;&gt;Welcome to iTALC!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;&lt;span style=&quot; font-size:12pt; font-weight:600; font-style:italic;&quot;&gt;Välkommen till iTALC!&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>Here you see the working-bar which contains several buttons. Each button is connected to a workspace. Just take a look at the available workspaces by clicking on the corresponding button.</source>
        <translation>Här kan du se arbetsfältet som innehåller flera knappar. Varje knapp är ansluten till en arbetsyta. Ta en titt på de tillgängliga arbetsytorna genom att klicka på de motsvarande knapparna.</translation>
    </message>
    <message>
        <source>Using the classroom-manager you can manage your classrooms and computers. You can also see which users are logged in.</source>
        <translation>Du kan hantera dina klassrum och datorer med klassrumshanteraren. Du kan även se vilka användare som är inloggade.</translation>
    </message>
    <message>
        <source>The snapshot-workspace is a very useful tool. It let&apos;s you manage the snapshots you made.</source>
        <translation>Arbetsytan för skärmbilder är ett mycket användbart verktyg. Det låter dig hantera de skärmbilder som du har tagit.</translation>
    </message>
    <message>
        <source>Of course you can configure iTALC. This is usually done using the configuration-workspace.</source>
        <translation>Du kan så klart även konfigurera iTALC. Detta sker oftast i arbetsytan för konfiguration.</translation>
    </message>
    <message>
        <source>About iTALC</source>
        <translation>Om iTALC</translation>
    </message>
</context>
<context>
    <name>OverviewWidget</name>
    <message>
        <source>Overview</source>
        <translation>Översikt</translation>
    </message>
    <message>
        <source>Some basic information on iTALC and how to use it.</source>
        <translation>Grundläggande information om iTALC och hur man använder det.</translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Please enter your username and password in order to access iTALC clients.</source>
        <translation>Ange ditt användarnamn och lösenord för att komma åt iTALC-klienter.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Användarnamn</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Lösenord</translation>
    </message>
    <message>
        <source>iTALC Logon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <source>iTALC Client %1 on %2:%3</source>
        <translation>Klient iTALC %1 na %2:%3</translation>
    </message>
    <message>
        <source>Unable to register service &apos;%1&apos;.</source>
        <translation>Nemôžem zaregistrovať službu &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not registered.</source>
        <translation>Nemôžem kontaktovat Správcu služieb (máte potrebné oprávnenie?!) - služba &apos;%1&apos; nebola zaregistrovaná.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; is already registered.</source>
        <translation>Služba &apos;%1&apos; je už registrovaná.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be registered.</source>
        <translation>Nemôžem zaregistrovať službu &apos;%1&apos;.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; was successfully registered.</source>
        <translation>Služba &apos;%1&apos; bola úspešne registrovaná.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be stopped.</source>
        <translation>Službu &apos;%1&apos; nie je možné zastaviť.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; has been unregistered.</source>
        <translation>Služba &apos;%1&apos; bola odregistrovaná.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; isn&apos;t registered and therefore can&apos;t be unregistered.</source>
        <translation>Služba &apos;%1&apos; nie je registrovaná a preto ju nemôžeme odregistrovať.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be unregistered.</source>
        <translation>Službu &apos;%1&apos; nebolo možné odregistrovať.</translation>
    </message>
    <message>
        <source>The service &apos;%1&apos; could not be found.</source>
        <translation>Služba &apos;%1&apos; sa nedá nájsť.</translation>
    </message>
    <message>
        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not unregistered.</source>
        <translation>Nemôžem kontaktovať Správcu služieb (máte potrebné oprávnenie?!) - služba &apos;%1&apos; sa nedá odregistrovať.</translation>
    </message>
    <message>
        <source>The Service Control Manager could not be contacted (do you have the necessary rights?!) - the service &apos;%1&apos; was not stopped.</source>
        <translation>Nemôžem kontaktovať Správcu služieb (máte potrebné oprávnenie?!) - služba &apos;%1&apos; nebola zastavená.</translation>
    </message>
</context>
<context>
    <name>RemoteControlWidget</name>
    <message>
        <source>View live (%1 @ %2)</source>
        <translation>Visa live (%1 @ %2)</translation>
    </message>
    <message>
        <source>Remote control (%1 @ %2)</source>
        <translation>Fjärrstyrning (%1 @ %2)</translation>
    </message>
    <message>
        <source>unknown user</source>
        <translation>okänd användare</translation>
    </message>
</context>
<context>
    <name>RemoteControlWidgetToolBar</name>
    <message>
        <source>View only</source>
        <translation>Visa endast</translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation>Fjärrstyrning</translation>
    </message>
    <message>
        <source>Lock student</source>
        <translation>Lås student</translation>
    </message>
    <message>
        <source>Unlock student</source>
        <translation>Lås upp student</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Skärmbild</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Helskärm</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>Fönster</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Avsluta</translation>
    </message>
    <message>
        <source>Connecting %1</source>
        <translation>Ansluter %1</translation>
    </message>
    <message>
        <source>Connected.</source>
        <translation>Ansluten.</translation>
    </message>
</context>
<context>
    <name>RemoteLogonDialog</name>
    <message>
        <source>Remote logon</source>
        <translation type="unfinished">Fjärrinloggning</translation>
    </message>
    <message>
        <source>Use the fields below to enter the username, password and optional the domain name. These information will be used to logon the computer(s).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished">Användarnamn</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished">Lösenord</translation>
    </message>
    <message>
        <source>Domain</source>
        <translation type="unfinished">Domän</translation>
    </message>
</context>
<context>
    <name>RunCommandsDialog</name>
    <message>
        <source>Run commands</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please enter the commands to run on the selected client(s). You can separate multiple commands by line.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Snapshot</name>
    <message>
        <source>unknown</source>
        <translation>okänd</translation>
    </message>
    <message>
        <source>Could not take a snapshot as directory %1 doesn&apos;t exist and couldn&apos;t be created.</source>
        <translation>Kunde inte ta en skärmbild eftersom katalogen %1 inte finns och inte kunde skapas.</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Skärmbild</translation>
    </message>
</context>
<context>
    <name>SnapshotList</name>
    <message>
        <source>Snapshots</source>
        <translation>Skärmbilder</translation>
    </message>
    <message>
        <source>Simply manage the snapshots you made using this workspace.</source>
        <translation>Hantera enkelt de skärmbilder som du skapat med denna arbetsyta.</translation>
    </message>
</context>
<context>
    <name>Snapshots</name>
    <message>
        <source>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;All snapshots you made are listed here. You can make snapshots by selecting the according entry in the context-menu of a client-window. These snapshosts can be managed using the buttons below.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot; font-family:&apos;Sans Serif&apos;; font-size:9pt; font-weight:400; font-style:normal; text-decoration:none;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;All snapshots you made are listed here. Du kan skapa skärmbilder genom att välja lämpligt objekt i sammanhangsmenyn för ett klientfönster. Dessa skärmbilder kan sedan hanteras med nedanstående knappar.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <source>User:</source>
        <translation>Användare:</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Värd:</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Datum:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Tid:</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Visa</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ta bort</translation>
    </message>
</context>
<context>
    <name>SupportDialog</name>
    <message>
        <source>Support</source>
        <translation type="unfinished">Support</translation>
    </message>
    <message>
        <source>Please enter the IP address or the name of the host to which you want to connect.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TextMessageDialog</name>
    <message>
        <source>Send text message</source>
        <translation type="unfinished">Skicka textmeddelande</translation>
    </message>
    <message>
        <source>Use the field below to type your message which will be sent to all selected users.</source>
        <translation type="unfinished">Använd fältet nedan för att skriva ditt meddelande som ska skickas till alla markerade användare.</translation>
    </message>
</context>
<context>
    <name>VncView</name>
    <message>
        <source>Establishing connection to %1 ...</source>
        <translation>Etablerar anslutning till %1...</translation>
    </message>
</context>
<context>
    <name>clientMenu</name>
    <message>
        <source>Overview</source>
        <translation>Översikt</translation>
    </message>
    <message>
        <source>Fullscreen demo</source>
        <translation>Demo i helskärm</translation>
    </message>
    <message>
        <source>Window demo</source>
        <translation>Demo i fönster</translation>
    </message>
    <message>
        <source>Locked display</source>
        <translation>Låst skärm</translation>
    </message>
    <message>
        <source>View live</source>
        <translation>Visa live</translation>
    </message>
    <message>
        <source>Remote control</source>
        <translation>Fjärrstyrning</translation>
    </message>
    <message>
        <source>Let student show demo</source>
        <translation>Låt student visa demo</translation>
    </message>
    <message>
        <source>Send text message</source>
        <translation>Skicka textmeddelande</translation>
    </message>
    <message>
        <source>Logout user</source>
        <translation>Logga ut användare</translation>
    </message>
    <message>
        <source>Take a snapshot</source>
        <translation>Ta en skärmbild</translation>
    </message>
    <message>
        <source>Power on</source>
        <translation>Starta</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Starta om</translation>
    </message>
    <message>
        <source>Power down</source>
        <translation>Stäng av</translation>
    </message>
    <message>
        <source>Execute commands</source>
        <translation>Kör kommandon</translation>
    </message>
</context>
</TS>
